@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013, Allen B. Riddell
+# Copyright (c) 2013-2014, PyStan developers
 #
 # This file is licensed under Version 3.0 of the GNU General Public
 # License. See LICENSE for a text of the license.
@@ -217,7 +217,7 @@ def stan(file=None, model_name="anon_model", model_code=None, fit=None,
         dependency among random number streams. By default, seed is
         ``random.randint(0, MAX_UINT)``.
 
-    algorithm : {"NUTS", "HMC"}, optional
+    algorithm : {"NUTS", "HMC", "Fixed_param"}, optional
         One of algorithms that are implemented in Stan such as the No-U-Turn
         sampler (NUTS, Hoffman and Gelman 2011) and static HMC.
 
