@@ -6,7 +6,7 @@ by the Cython file `stan_fit.pxd`.
 
 """
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013, Allen B. Riddell
+# Copyright (c) 2013-2014, PyStan developers
 #
 # This file is licensed under Version 3.0 of the GNU General Public
 # License. See LICENSE for a text of the license.
@@ -155,6 +155,8 @@ def _summary(fit, pars=None, probs=None, **kwargs):
         pars = fit.sim['pars_oi']
     elif isinstance(pars, string_types):
         pars = [pars]
+    pars = _remove_empty_pars(pars, fit.sim['pars_oi'], fit.sim['dims_oi'])
+
     if probs is None:
         probs = (0.025, 0.25, 0.5, 0.75, 0.975)
     ss = _summary_sim(fit.sim, pars, probs)
@@ -458,6 +460,8 @@ def _get_valid_stan_args(base_args=None):
     args['sample_file'] = args.get('sample_file', '').encode('ascii')
     args['diagnostic_file_flag'] = True if args.get('diagnostic_file') else False
     args['diagnostic_file'] = args.get('diagnostic_file', '').encode('ascii')
+    # NB: argument named "seed" not "random_seed"
+    args['random_seed'] = args.get('seed', int(time.time()))
 
     if args['method'] == stan_args_method_t.SAMPLING:
         args['ctrl'] = args.get('ctrl', dict(sampling=dict()))
@@ -472,20 +476,6 @@ def _get_valid_stan_args(base_args=None):
         args['ctrl']['sampling']['iter_save'] = iter_save_wo_warmup + 1 + (warmup - 1) // thin
         refresh = iter // 10 if iter >= 20 else 1
         args['ctrl']['sampling']['refresh'] = args.get('refresh', refresh)
-        # NB: argument named "seed" not "random_seed"
-        args['random_seed'] = args.get('seed', int(time.time()))
-
-        algorithm = args.get('algorithm', 'NUTS')
-        if algorithm == 'HMC':
-            args['ctrl']['sampling']['algorithm'] = sampling_algo_t.HMC
-        elif algorithm == 'Metropolis':
-            args['ctrl']['sampling']['algorithm'] = sampling_algo_t.Metropolis
-        elif algorithm == 'NUTS':
-            args['ctrl']['sampling']['algorithm'] = sampling_algo_t.NUTS
-        else:
-            msg = "Invalid value for parameter algorithm (found {}; " \
-                "require HMC, Metropolis, or NUTS).".format(algorithm)
-            raise ValueError(msg)
 
         ctrl_lst = args.get('control', dict())
         ctrl_sampling = args['ctrl']['sampling']
@@ -501,6 +491,20 @@ def _get_valid_stan_args(base_args=None):
         ctrl_sampling['stepsize'] = ctrl_lst.get("stepsize", 1.0)
         ctrl_sampling['stepsize_jitter'] = ctrl_lst.get("stepsize_jitter", 0.0)
 
+        algorithm = args.get('algorithm', 'NUTS')
+        if algorithm == 'HMC':
+            args['ctrl']['sampling']['algorithm'] = sampling_algo_t.HMC
+        elif algorithm == 'Metropolis':
+            args['ctrl']['sampling']['algorithm'] = sampling_algo_t.Metropolis
+        elif algorithm == 'NUTS':
+            args['ctrl']['sampling']['algorithm'] = sampling_algo_t.NUTS
+        elif algorithm == 'Fixed_param':
+            args['ctrl']['sampling']['algorithm'] = sampling_algo_t.Fixed_param
+        else:
+            msg = "Invalid value for parameter algorithm (found {}; " \
+                "require HMC, Metropolis, NUTS, or Fixed_param).".format(algorithm)
+            raise ValueError(msg)
+
         metric = ctrl_lst.get('metric')
         if metric == "unit_e":
             ctrl_sampling['metric'] = sampling_metric_t.UNIT_E
@@ -517,6 +521,8 @@ def _get_valid_stan_args(base_args=None):
                 ctrl_sampling['int_time'] = ctrl_lst.get('int_time', 6.283185307179586476925286766559005768e+00)
             elif ctrl_sampling['algorithm'] == sampling_algo_t.Metropolis:
                 pass
+            elif ctrl_sampling['algorithm'] == sampling_algo_t.Fixed_param:
+                pass
 
     elif args['method'] == stan_args_method_t.OPTIM:
         args['ctrl'] = args.get('ctrl', dict(optim=dict()))
@@ -980,6 +986,31 @@ def _rdump_value_to_numpy(s):
     return arr
 
 
+def _remove_empty_pars(pars, pars_oi, dims_oi):
+    """
+    Remove parameters that are actually empty. For example, the parameter
+    y would be removed with the following model code:
+
+        transformed data { int n; n <- 0; }
+        parameters { real y[n]; }
+
+    Parameters
+    ----------
+    pars: iterable of str
+    pars_oi: list of str
+    dims_oi: list of list of int
+
+    Returns
+    -------
+    pars_trimmed: list of str
+    """
+    pars = list(pars)
+    for par, dim in zip(pars_oi, dims_oi):
+        if par in pars and np.prod(dim) == 0:
+            del pars[pars.index(par)]
+    return pars
+
+
 def read_rdump(filename):
     """
     Read data formatted using the R dump format
