@@ -18,6 +18,8 @@
 #include <stan/agrad/fwd/matrix/mdivide_right_tri_low.hpp>
 #include <stan/agrad/fwd/matrix/multiply.hpp>
 #include <stan/agrad/fwd/matrix/multiply_lower_tri_self_transpose.hpp>
+#include <stan/agrad/fwd/matrix/qr_Q.hpp>
+#include <stan/agrad/fwd/matrix/qr_R.hpp>
 #include <stan/agrad/fwd/matrix/rows_dot_product.hpp>
 #include <stan/agrad/fwd/matrix/rows_dot_self.hpp>
 #include <stan/agrad/fwd/matrix/softmax.hpp>
