@@ -4,8 +4,8 @@
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_vector.hpp>
-#include <stan/math/matrix/validate_matching_sizes.hpp>
+#include <stan/math/error_handling/matrix/check_vector.hpp>
+#include <stan/math/error_handling/matrix/check_matching_sizes.hpp>
 #include <stan/agrad/fwd.hpp>
 #include <stan/agrad/fwd/matrix/typedefs.hpp>
 #include <stan/agrad/fwd/matrix/to_fvar.hpp>
@@ -19,9 +19,10 @@ namespace stan {
     fvar<T> 
     dot_product(const Eigen::Matrix<fvar<T>, R1, C1>& v1, 
                 const Eigen::Matrix<fvar<T>, R2, C2>& v2) {
-      stan::math::validate_vector(v1,"dot_product");
-      stan::math::validate_vector(v2,"dot_product");
-      stan::math::validate_matching_sizes(v1,v2,"dot_product");
+      stan::math::check_vector("dot_product(%1%)",v1,"v1",(double*)0);
+      stan::math::check_vector("dot_product(%1%)",v2,"v2",(double*)0);
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
 
       fvar<T> ret(0,0);
       for(size_type i = 0; i < v1.size(); i++)
@@ -34,9 +35,10 @@ namespace stan {
     fvar<T> 
     dot_product(const Eigen::Matrix<fvar<T>, R1, C1>& v1, 
                 const Eigen::Matrix<double, R2, C2>& v2) {
-      stan::math::validate_vector(v1,"dot_product");
-      stan::math::validate_vector(v2,"dot_product");
-      stan::math::validate_matching_sizes(v1,v2,"dot_product");
+      stan::math::check_vector("dot_product(%1%)",v1,"v1",(double*)0);
+      stan::math::check_vector("dot_product(%1%)",v2,"v2",(double*)0);
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
 
       fvar<T> ret(0,0);
       for(size_type i = 0; i < v1.size(); i++)
@@ -49,9 +51,10 @@ namespace stan {
     fvar<T> 
     dot_product(const Eigen::Matrix<double, R1, C1>& v1, 
                 const Eigen::Matrix<fvar<T>, R2, C2>& v2) {
-      stan::math::validate_vector(v1,"dot_product");
-      stan::math::validate_vector(v2,"dot_product");
-      stan::math::validate_matching_sizes(v1,v2,"dot_product");
+      stan::math::check_vector("dot_product(%1%)",v1,"v1",(double*)0);
+      stan::math::check_vector("dot_product(%1%)",v2,"v2",(double*)0);
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
 
       fvar<T> ret(0,0);
       for(size_type i = 0; i < v1.size(); i++)
@@ -65,8 +68,8 @@ namespace stan {
     dot_product(const Eigen::Matrix<fvar<T>, R1, C1>& v1, 
                 const Eigen::Matrix<fvar<T>, R2, C2>& v2,
                 size_type& length) {
-      stan::math::validate_vector(v1,"dot_product");
-      stan::math::validate_vector(v2,"dot_product");
+      stan::math::check_vector("dot_product(%1%)",v1,"v1",(double*)0);
+      stan::math::check_vector("dot_product(%1%)",v2,"v2",(double*)0);
 
       fvar<T> ret(0,0);
       for(size_type i = 0; i < length; i++)
@@ -80,8 +83,8 @@ namespace stan {
     dot_product(const Eigen::Matrix<fvar<T>, R1, C1>& v1, 
                 const Eigen::Matrix<double, R2, C2>& v2,
                 size_type& length) {
-      stan::math::validate_vector(v1,"dot_product");
-      stan::math::validate_vector(v2,"dot_product");
+      stan::math::check_vector("dot_product(%1%)",v1,"v1",(double*)0);
+      stan::math::check_vector("dot_product(%1%)",v2,"v2",(double*)0);
 
       fvar<T> ret(0,0);
       for(size_type i = 0; i < length; i++)
@@ -95,8 +98,8 @@ namespace stan {
     dot_product(const Eigen::Matrix<double, R1, C1>& v1, 
                 const Eigen::Matrix<fvar<T>, R2, C2>& v2,
                 size_type& length) {
-      stan::math::validate_vector(v1,"dot_product");
-      stan::math::validate_vector(v2,"dot_product");
+      stan::math::check_vector("dot_product(%1%)",v1,"v1",(double*)0);
+      stan::math::check_vector("dot_product(%1%)",v2,"v2",(double*)0);
 
       fvar<T> ret(0,0);
       for(size_type i = 0; i < length; i++)
@@ -109,7 +112,8 @@ namespace stan {
     fvar<T>
     dot_product(const std::vector<fvar<T> >& v1,
                 const std::vector<fvar<T> >& v2) {
-      stan::math::validate_matching_sizes(v1,v2,"dot_product");
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       fvar<T> ret(0,0);
       for (size_t i = 0; i < v1.size(); i++)
         ret += v1.at(i) * v2.at(i);
@@ -121,7 +125,8 @@ namespace stan {
     fvar<T>
     dot_product(const std::vector<double>& v1,
                 const std::vector<fvar<T> >& v2) {
-      stan::math::validate_matching_sizes(v1,v2,"dot_product");
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       fvar<T> ret(0,0);
       for (size_t i = 0; i < v1.size(); i++)
         ret += v1.at(i) * v2.at(i);
@@ -133,7 +138,8 @@ namespace stan {
     fvar<T>
     dot_product(const std::vector<fvar<T> >& v1,
                 const std::vector<double>& v2) {
-      stan::math::validate_matching_sizes(v1,v2,"dot_product");
+      stan::math::check_matching_sizes("dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       fvar<T> ret(0,0);
       for (size_t i = 0; i < v1.size(); i++)
         ret += v1.at(i) * v2.at(i);
