@@ -4,13 +4,14 @@
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_square.hpp>
-#include <stan/math/matrix/validate_multiplicable.hpp>
+#include <stan/math/matrix/mdivide_left.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
 #include <stan/agrad/fwd/matrix/typedefs.hpp>
 #include <stan/agrad/fwd/matrix/to_fvar.hpp>
 #include <stan/agrad/fwd/matrix/multiply.hpp>
 #include <stan/agrad/fwd/matrix/inverse.hpp>
 #include <stan/agrad/fwd/fvar.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace agrad {
@@ -22,8 +23,9 @@ namespace stan {
                          const Eigen::Matrix<fvar<T>, R2, C2>& b) {
       using stan::math::multiply;      
       using stan::math::mdivide_left;
-      stan::math::validate_square(A,"mdivide_left");
-      stan::math::validate_multiplicable(A,b,"mdivide_left");
+      stan::math::check_square("mdivide_left_tri_low(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_tri_low(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R1,C2> inv_A_mult_b(A.rows(),b.cols());
       Eigen::Matrix<T,R1,C2> inv_A_mult_deriv_b(A.rows(),b.cols());
@@ -66,8 +68,9 @@ namespace stan {
                          const Eigen::Matrix<fvar<T>, R2, C2>& b) {
       using stan::math::multiply;      
       using stan::math::mdivide_left;
-      stan::math::validate_square(A,"mdivide_left");
-      stan::math::validate_multiplicable(A,b,"mdivide_left");
+      stan::math::check_square("mdivide_left_tri_low(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_tri_low(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R1,C2> inv_A_mult_b(A.rows(),b.cols());
       Eigen::Matrix<T,R1,C2> inv_A_mult_deriv_b(A.rows(),b.cols());
@@ -105,11 +108,11 @@ namespace stan {
                          const Eigen::Matrix<double, R2, C2>& b) {
       using stan::math::multiply;      
       using stan::math::mdivide_left;
-      stan::math::validate_square(A,"mdivide_left");
-      stan::math::validate_multiplicable(A,b,"mdivide_left");
+      stan::math::check_square("mdivide_left_tri_low(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_tri_low(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
-      Eigen::Matrix<T,R1,C2> 
-        inv_A_mult_b(A.rows(),b.cols());
+      Eigen::Matrix<T,R1,C2> inv_A_mult_b(A.rows(),b.cols());
       Eigen::Matrix<T,R1,C1> inv_A_mult_deriv_A(A.rows(),A.cols());
       Eigen::Matrix<T,R1,C1> val_A(A.rows(),A.cols()); 
       Eigen::Matrix<T,R1,C1> deriv_A(A.rows(),A.cols()); 
