@@ -4,8 +4,8 @@
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_multiplicable.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 #include <stan/agrad/rev/var.hpp>
 #include <stan/agrad/rev/matrix/typedefs.hpp>
 
@@ -297,8 +297,9 @@ namespace stan {
                      const Eigen::Matrix<var,R2,C2> &b) {
       Eigen::Matrix<var,R1,C2> res(b.rows(),b.cols());
       
-      stan::math::validate_square(A,"mdivide_left_tri");
-      stan::math::validate_multiplicable(A,b,"mdivide_left_tri");
+      stan::math::check_square("mdivide_left_tri(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_tri(%1%)",A,"A",
+                                      b,"b",(double*)0);
       
       // NOTE: this is not a memory leak, this vari is used in the 
       // expression graph to evaluate the adjoint, but is not needed
@@ -319,8 +320,9 @@ namespace stan {
                      const Eigen::Matrix<var,R2,C2> &b) {
       Eigen::Matrix<var,R1,C2> res(b.rows(),b.cols());
       
-      stan::math::validate_square(A,"mdivide_left_tri");
-      stan::math::validate_multiplicable(A,b,"mdivide_left_tri");
+      stan::math::check_square("mdivide_left_tri(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_tri(%1%)",A,"A",
+                                      b,"b",(double*)0);
       
       // NOTE: this is not a memory leak, this vari is used in the 
       // expression graph to evaluate the adjoint, but is not needed
@@ -341,8 +343,9 @@ namespace stan {
                      const Eigen::Matrix<double,R2,C2> &b) {
       Eigen::Matrix<var,R1,C2> res(b.rows(),b.cols());
       
-      stan::math::validate_square(A,"mdivide_left_tri");
-      stan::math::validate_multiplicable(A,b,"mdivide_left_tri");
+      stan::math::check_square("mdivide_left_tri(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left_tri(%1%)",A,"A",
+                                      b,"b",(double*)0);
       
       // NOTE: this is not a memory leak, this vari is used in the 
       // expression graph to evaluate the adjoint, but is not needed
