@@ -89,13 +89,14 @@ namespace stan {
 
 
     struct set_fun_type_named {
-      template <typename T1, typename T2, typename T3, typename T4>
-      struct result { typedef fun type; };
+      template <typename T1, typename T2, typename T3, typename T4, typename T5>
+      struct result { typedef void type; };
 
-      fun operator()(fun& fun,
-                     const var_origin& var_origin,
-                     bool& pass,
-                     std::ostream& error_msgs) const {
+      void operator()(expression& fun_result,
+                      fun& fun,
+                      const var_origin& var_origin,
+                      bool& pass,
+                      std::ostream& error_msgs) const {
         std::vector<expr_type> arg_types;
         for (size_t i = 0; i < fun.args_.size(); ++i)
           arg_types.push_back(fun.args_[i].expression_type());
@@ -103,8 +104,40 @@ namespace stan {
                                                                     arg_types,
                                                                     error_msgs);
 
-        pass = !has_rng_suffix(fun.name_) || var_origin == derived_origin;
-        if (fun.name_ == "abs"
+
+        if (has_rng_suffix(fun.name_)) {  
+          if (!( var_origin == derived_origin
+                 || var_origin == function_argument_origin_rng )) {
+            error_msgs << "random number generators only allowed in"
+                       << " generated quantities block or"
+                       << " user-defined functions with names ending in _rng"
+                       << "; found function=" << fun.name_
+                       << " in block=";
+          print_var_origin(error_msgs,var_origin);
+          error_msgs << std::endl;
+          pass = false;
+          return;
+          }
+        }
+
+        if (has_lp_suffix(fun.name_)) {
+          if (!( var_origin == parameter_origin
+                 || var_origin == transformed_parameter_origin
+                 || var_origin == function_argument_origin
+                 || var_origin == local_origin )) {
+            error_msgs << "lp suffixed functions only allowed in"
+                       << " transformed parameter, function argument, or model"
+                       << " blocks;  found function=" << fun.name_ 
+                       << " in block=";
+            print_var_origin(error_msgs,var_origin);
+            error_msgs << std::endl;
+            pass = false;
+            return;
+          }
+        }
+
+        if (fun.name_ == "abs" 
+            && fun.args_.size() > 0 
             && fun.args_[0].expression_type().is_primitive_double()) {
           error_msgs << "Warning: Function abs(real) is deprecated."
                      << std::endl
@@ -114,33 +147,64 @@ namespace stan {
                      << std::endl << std::endl;
         }
 
-
-        if (!pass) {
-          error_msgs << "random number generators only allowed in generated quantities block"
-                     << "; found function=" << fun.name_
-                     << " in block=";
-          print_var_origin(error_msgs,var_origin);
-          error_msgs << std::endl;
-        }
-
-        return fun;
+        fun_result = fun;
+        pass = true;
       }
     };
     boost::phoenix::function<set_fun_type_named> set_fun_type_named_f;
 
-
  
+    struct exponentiation_expr {
+      template <typename T1, typename T2, typename T3, typename T4, typename T5>
+      struct result { typedef void type; };
+
+      void operator()(expression& expr1,
+                      const expression& expr2,
+                      const var_origin& var_origin,
+                      bool& pass,
+                      std::ostream& error_msgs) const {
+
+        //        if (expr1.expression_type().is_vector() 
+        //            && !expr2.expression_type().is_primitive()) {
+        // handle raising each member of a vector to a power?
+        // }
+        print_var_origin(error_msgs,var_origin);
+        if (!expr1.expression_type().is_primitive() 
+            || !expr2.expression_type().is_primitive()) {
+          error_msgs << "arguments to ^ must be primitive (real or int)"
+                     << "; cannot exponentiate "
+                     << expr1.expression_type()
+                     << " by " 
+                     << expr2.expression_type()
+                     << " in block=";
+          print_var_origin(error_msgs,var_origin);
+          error_msgs << std::endl;
+          pass = false;
+          return;
+        }
+        std::vector<expression> args;
+        args.push_back(expr1);
+        args.push_back(expr2);
+        set_fun_type sft;
+        fun f("pow",args);
+        sft(f,error_msgs);
+        expr1 = expression(f);
+      }
+    };
+    boost::phoenix::function<exponentiation_expr> exponentiation_f;
+
     struct multiplication_expr {
       template <typename T1, typename T2, typename T3>
-      struct result { typedef expression type; };
+      struct result { typedef void type; };
 
-      expression operator()(expression& expr1,
-                            const expression& expr2,
-                            std::ostream& error_msgs) const {
+      void operator()(expression& expr1,
+                      const expression& expr2,
+                      std::ostream& error_msgs) const {
 
         if (expr1.expression_type().is_primitive()
             && expr2.expression_type().is_primitive()) {
-          return expr1 *= expr2;
+          expr1 *= expr2;;
+          return;
         }
         std::vector<expression> args;
         args.push_back(expr1);
@@ -148,20 +212,20 @@ namespace stan {
         set_fun_type sft;
         fun f("multiply",args);
         sft(f,error_msgs);
-        return expression(f);
+        expr1 = expression(f);
       }
     };
-    boost::phoenix::function<multiplication_expr> multiplication;
+    boost::phoenix::function<multiplication_expr> multiplication_f;
 
     void generate_expression(const expression& e, std::ostream& o);
 
     struct division_expr {
       template <typename T1, typename T2, typename T3>
-      struct result { typedef expression type; };
+      struct result { typedef void type; };
 
-      expression operator()(expression& expr1,
-                            const expression& expr2,
-                            std::ostream& error_msgs) const {
+      void operator()(expression& expr1,
+                      const expression& expr2,
+                      std::ostream& error_msgs) const {
         if (expr1.expression_type().is_primitive_int() 
             && expr2.expression_type().is_primitive_int()) {
           // getting here, but not printing?  only print error if problems?
@@ -178,7 +242,8 @@ namespace stan {
             
         if (expr1.expression_type().is_primitive()
             && expr2.expression_type().is_primitive()) {
-          return expr1 /= expr2;
+          expr1 /= expr2;
+          return;
         }
         std::vector<expression> args;
         args.push_back(expr1);
@@ -189,27 +254,23 @@ namespace stan {
             && expr2.expression_type().type() == MATRIX_T) {
           fun f("mdivide_right",args);
           sft(f,error_msgs);
-          return expression(f);
+          expr1 = expression(f);
+          return;
         }
-        
         fun f("divide",args);
         sft(f,error_msgs);
-        return expression(f);
+        expr1 = expression(f);
       }
     };
-    boost::phoenix::function<division_expr> division;
+    boost::phoenix::function<division_expr> division_f;
 
     struct left_division_expr {
       template <typename T1, typename T2, typename T3>
-      struct result { typedef expression type; };
+      struct result { typedef void type; };
 
-      expression operator()(expression& expr1,
-                            const expression& expr2,
-                            std::ostream& error_msgs) const {
-        if (expr1.expression_type().is_primitive()
-            && expr2.expression_type().is_primitive()) {
-          return expr1 /= expr2;
-        }
+      void operator()(expression& expr1,
+                      const expression& expr2,
+                      std::ostream& error_msgs) const {
         std::vector<expression> args;
         args.push_back(expr1);
         args.push_back(expr2);
@@ -219,27 +280,29 @@ namespace stan {
                 || expr2.expression_type().type() == MATRIX_T)) {
           fun f("mdivide_left",args);
           sft(f,error_msgs);
-          return expression(f);
+          expr1 = expression(f);
+          return;
         }
         fun f("divide_left",args); // this doesn't exist, so will
                                    // throw error on purpose
         sft(f,error_msgs);
-        return expression(f);
+        expr1 = expression(f);
       }
     };
-    boost::phoenix::function<left_division_expr> left_division;
+    boost::phoenix::function<left_division_expr> left_division_f;
 
     struct elt_multiplication_expr {
       template <typename T1, typename T2, typename T3>
-      struct result { typedef expression type; };
+      struct result { typedef void type; };
 
-      expression operator()(expression& expr1,
-                            const expression& expr2,
-                            std::ostream& error_msgs) const {
+      void operator()(expression& expr1,
+                      const expression& expr2,
+                      std::ostream& error_msgs) const {
 
         if (expr1.expression_type().is_primitive()
             && expr2.expression_type().is_primitive()) {
-          return expr1 *= expr2;
+          expr1 *= expr2;
+          return;
         }
         std::vector<expression> args;
         args.push_back(expr1);
@@ -247,23 +310,23 @@ namespace stan {
         set_fun_type sft;
         fun f("elt_multiply",args);
         sft(f,error_msgs);
-        return expression(f);
-        return expr1 += expr2;
+        expr1 = expression(f);
       }
     };
-    boost::phoenix::function<elt_multiplication_expr> elt_multiplication;
+    boost::phoenix::function<elt_multiplication_expr> elt_multiplication_f;
 
     struct elt_division_expr {
       template <typename T1, typename T2, typename T3>
-      struct result { typedef expression type; };
+      struct result { typedef void type; };
 
-      expression operator()(expression& expr1,
-                            const expression& expr2,
-                            std::ostream& error_msgs) const {
+      void operator()(expression& expr1,
+                      const expression& expr2,
+                      std::ostream& error_msgs) const {
 
         if (expr1.expression_type().is_primitive()
             && expr2.expression_type().is_primitive()) {
-          return expr1 /= expr2;
+          expr1 /= expr2;
+          return;
         }
         std::vector<expression> args;
         args.push_back(expr1);
@@ -271,11 +334,10 @@ namespace stan {
         set_fun_type sft;
         fun f("elt_divide",args);
         sft(f,error_msgs);
-        return expression(f);
-        return expr1 += expr2;
+        expr1 = expression(f);
       }
     };
-    boost::phoenix::function<elt_division_expr> elt_division;
+    boost::phoenix::function<elt_division_expr> elt_division_f;
 
     // Cut-and-Paste from Spirit examples, including comment:  We
     // should be using expression::operator-. There's a bug in phoenix
@@ -283,40 +345,43 @@ namespace stan {
     // so. Phoenix will be switching to BOOST_TYPEOF. In the meantime,
     // we will use a phoenix::function below:
     struct negate_expr {
-      template <typename T1, typename T2>
-      struct result { typedef expression type; };
+      template <typename T1, typename T2, typename T3>
+      struct result { typedef void type; };
 
-      expression operator()(const expression& expr,
-                            std::ostream& error_msgs) const {
+      void operator()(expression& expr_result,
+                      const expression& expr,
+                      std::ostream& error_msgs) const {
         if (expr.expression_type().is_primitive()) {
-          return expression(unary_op('-', expr));
+          expr_result = expression(unary_op('-', expr));
+          return;
         }
         std::vector<expression> args;
         args.push_back(expr);
         set_fun_type sft;
         fun f("minus",args);
         sft(f,error_msgs);
-        return expression(f);
+        expr_result = expression(f);
       }
     };
     boost::phoenix::function<negate_expr> negate_expr_f;
 
     struct logical_negate_expr {
-      template <typename T1, typename T2>
-      struct result { typedef expression type; };
+      template <typename T1, typename T2, typename T3>
+      struct result { typedef void type; };
 
-      expression operator()(const expression& expr,
-                            std::ostream& error_msgs) const {
+      void operator()(expression& expr_result,
+                      const expression& expr,
+                      std::ostream& error_msgs) const {
         if (!expr.expression_type().is_primitive()) {
           error_msgs << "logical negation operator ! only applies to int or real types; ";
-          return expression();
+          expr_result = expression();
         }
         std::vector<expression> args;
         args.push_back(expr);
         set_fun_type sft;
         fun f("logical_negation",args);
         sft(f,error_msgs);
-        return expression(f);
+        expr_result = expression(f);
       }
     };
     boost::phoenix::function<logical_negate_expr> logical_negate_expr_f;
@@ -327,6 +392,7 @@ namespace stan {
 
       expression operator()(const expression& expr,
                             std::ostream& error_msgs) const {
+
         if (expr.expression_type().is_primitive()) {
           return expr; // transpose of basic is self -- works?
         }
@@ -342,20 +408,19 @@ namespace stan {
 
     struct add_expression_dimss {
       template <typename T1, typename T2, typename T3, typename T4>
-      struct result { typedef T1 type; };
-      expression operator()(expression& expression,
-                            std::vector<std::vector<stan::gm::expression> >& dimss,
-                            bool& pass,
-                            std::ostream& error_msgs) const {
+      struct result { typedef void type; };
+      void operator()(expression& expression,
+                      std::vector<std::vector<stan::gm::expression> >& dimss,
+                      bool& pass,
+                      std::ostream& error_msgs) const {
         index_op iop(expression,dimss);
         iop.infer_type();
         if (iop.type_.is_ill_formed()) {
           error_msgs << "indexes inappropriate for expression." << std::endl;
           pass = false;
-        } else {
-          pass = true;
-        }
-        return iop;
+        } 
+        pass = true;
+        expression = iop;
       }
     };
     boost::phoenix::function<add_expression_dimss> add_expression_dimss_f;
@@ -453,51 +518,63 @@ namespace stan {
         = ( negated_factor_r(_r1)                       
             [_val = _1]
             >> *( (lit('*') > negated_factor_r(_r1)     
-                               [_val = multiplication(_val,_1,
-                                                      boost::phoenix::ref(error_msgs_))])
+                              [multiplication_f(_val,_1,
+                                                boost::phoenix::ref(error_msgs_))])
                   | (lit('/') > negated_factor_r(_r1)   
-                                 [_val = division(_val,_1,boost::phoenix::ref(error_msgs_))])
+                                [division_f(_val,_1,boost::phoenix::ref(error_msgs_))])
                   | (lit('\\') > negated_factor_r(_r1)   
-                                  [_val = left_division(_val,_1,
-                                                        boost::phoenix::ref(error_msgs_))])
+                                 [left_division_f(_val,_1,
+                                                   boost::phoenix::ref(error_msgs_))])
                   | (lit(".*") > negated_factor_r(_r1)   
-                                  [_val = elt_multiplication(_val,_1,
-                                                         boost::phoenix::ref(error_msgs_))])
+                                 [elt_multiplication_f(_val,_1,
+                                                        boost::phoenix::ref(error_msgs_))])
                   | (lit("./") > negated_factor_r(_r1)   
-                                  [_val = elt_division(_val,_1,
-                                                       boost::phoenix::ref(error_msgs_))])
+                                 [elt_division_f(_val,_1,
+                                                 boost::phoenix::ref(error_msgs_))])
                    )
              )
         ;
 
-
       negated_factor_r 
         = lit('-') >> negated_factor_r(_r1) 
-                      [_val = negate_expr_f(_1,boost::phoenix::ref(error_msgs_))]
+                      [negate_expr_f(_val,_1,boost::phoenix::ref(error_msgs_))]
         | lit('!') >> negated_factor_r(_r1) 
-                      [_val = logical_negate_expr_f(_1,boost::phoenix::ref(error_msgs_))]
+                      [logical_negate_expr_f(_val,_1,boost::phoenix::ref(error_msgs_))]
         | lit('+') >> negated_factor_r(_r1)  [_val = _1]
+        | exponentiated_factor_r(_r1) [_val = _1]
         | indexed_factor_r(_r1) [_val = _1];
 
 
+      exponentiated_factor_r.name("(optionally) exponentiated factor");
+      exponentiated_factor_r 
+        = ( factor_r(_r1) [_val = _1] 
+            >> lit('^') 
+            > negated_factor_r(_r1)
+            [exponentiation_f(_val,_1,_r1,_pass,
+                              boost::phoenix::ref(error_msgs_))] 
+            )
+        ;
+
       indexed_factor_r.name("(optionally) indexed factor [sub]");
       indexed_factor_r 
         = factor_r(_r1) [_val = _1]
         > * (  
              (+dims_r(_r1)) 
-               [_val = add_expression_dimss_f(_val, _1, _pass,
-                                            boost::phoenix::ref(error_msgs_))]
+               [add_expression_dimss_f(_val, _1, _pass,
+                                       boost::phoenix::ref(error_msgs_))]
                | 
                lit("'") 
                [_val = transpose_f(_val, boost::phoenix::ref(error_msgs_))] 
                )
         ;
+      
+
 
 
       factor_r.name("factor");
       factor_r =
-          fun_r(_r1)          [_val = set_fun_type_named_f(_1,_r1,_pass,
-                                                           boost::phoenix::ref(error_msgs_))]
+          fun_r(_r1)          [set_fun_type_named_f(_val,_1,_r1,_pass,
+                                                    boost::phoenix::ref(error_msgs_))]
         | variable_r          [_val = set_var_type_f(_1,boost::phoenix::ref(var_map_),
                                                      boost::phoenix::ref(error_msgs_),
                                                      _pass)]
