@@ -472,7 +472,7 @@ namespace stan {
       inline T scalar_pos() {
         T x(scalar());
         stan::math::check_positive("stan::io::scalar_pos(%1%)", x, 
-                                   "Constrained scalar");
+                                   "Constrained scalar", (double*)0);
         return x;
       }
 
@@ -517,7 +517,8 @@ namespace stan {
       inline T scalar_lb(const TL lb) {
         T x(scalar());
         stan::math::check_greater_or_equal("stan::io::scalar_lb(%1%)",
-                                           x, lb, "Constrained scalar");
+                                           x, lb, "Constrained scalar", 
+                                           (double*)0);
         return x;
       }
 
@@ -570,7 +571,8 @@ namespace stan {
       template <typename TU>
       inline T scalar_ub(TU ub) {
         T x(scalar());
-        stan::math::check_less_or_equal("stan::io::scalar_ub(%1%)", x, ub, "Constrained scalar");
+        stan::math::check_less_or_equal("stan::io::scalar_ub(%1%)", x, ub, 
+                                        "Constrained scalar", (double*)0);
         return x;
       }
 
@@ -623,7 +625,8 @@ namespace stan {
       template <typename TL, typename TU>
       inline T scalar_lub(const TL lb, const TU ub) {
         T x(scalar());
-        stan::math::check_bounded("stan::io::scalar_lub(%1%)", x, lb, ub, "Constrained scalar");
+        stan::math::check_bounded<T,TL,TU,T>
+          ("stan::io::scalar_lub(%1%)", x, lb, ub, "Constrained scalar",0);
         return x;
       }
 
@@ -673,7 +676,8 @@ namespace stan {
        */
       inline T prob() {
         T x(scalar());
-        stan::math::check_bounded("stan::io::prob(%1%)", x, 0, 1, "Constrained probability");
+        stan::math::check_bounded<T,double,double,double>
+          ("stan::io::prob(%1%)", x, 0, 1, "Constrained probability", 0);
         return x;
       }
 
@@ -719,7 +723,8 @@ namespace stan {
        */
       inline T corr() {
         T x(scalar());
-        stan::math::check_bounded("stan::io::corr(%1%)", x, -1, 1, "Correlation value");
+        stan::math::check_bounded<T,double,double,double>
+          ("stan::io::corr(%1%)", x, -1, 1, "Correlation value",0);
         return x;
       }
 
@@ -762,7 +767,8 @@ namespace stan {
        */
       inline vector_t unit_vector(size_t k) {
         vector_t theta(vector(k));
-        stan::math::check_unit_vector("stan::io::unit_vector(%1%)", theta, "Constrained vector");
+        stan::math::check_unit_vector("stan::io::unit_vector(%1%)", theta, "Constrained vector",
+                                      (double*)0);
         return theta;
       }
 
@@ -809,7 +815,8 @@ namespace stan {
        */
       inline vector_t simplex(size_t k) {
         vector_t theta(vector(k));
-        stan::math::check_simplex("stan::io::simplex(%1%)", theta, "Constrained vector");
+        stan::math::check_simplex("stan::io::simplex(%1%)", theta, "Constrained vector",
+                                  (double*)0);
         return theta;
       }
 
@@ -900,7 +907,9 @@ namespace stan {
        */
       inline vector_t positive_ordered(size_t k) {
         vector_t x(vector(k));
-        stan::math::check_positive_ordered("stan::io::positive_ordered(%1%)", x, "Constrained vector");
+        stan::math::check_positive_ordered("stan::io::positive_ordered(%1%)", 
+                                           x, "Constrained vector",
+                                           (double*)0);
         return x;
       }
 
@@ -944,7 +953,9 @@ namespace stan {
        */
       inline matrix_t cholesky_factor(size_t M, size_t N) {
         matrix_t y(matrix(M,N));
-        stan::math::check_cholesky_factor("stan::io::cholesky_factor(%1%)", y, "Constrained matrix");
+        stan::math::check_cholesky_factor("stan::io::cholesky_factor(%1%)", 
+                                          y, "Constrained matrix",
+                                          (double*)0);
         return y;
       }
 
@@ -995,7 +1006,8 @@ namespace stan {
        */
       inline matrix_t cov_matrix(size_t k) {
         matrix_t y(matrix(k,k));
-        stan::math::check_cov_matrix("stan::io::cov_matrix(%1%)", y, "Constrained matrix");
+        stan::math::check_cov_matrix("stan::io::cov_matrix(%1%)", y, "Constrained matrix",
+                                     (double*)0);
         return y;
       }
 
@@ -1040,7 +1052,9 @@ namespace stan {
        */
       inline matrix_t corr_matrix(size_t k) {
         matrix_t x(matrix(k,k));
-        stan::math::check_corr_matrix("stan::math::corr_matrix(%1%)", x, "Constrained matrix");
+        stan::math::check_corr_matrix("stan::math::corr_matrix(%1%)", 
+                                      x, "Constrained matrix",
+                                      (double*)0);
         return x;
       }
 
