@@ -8,7 +8,6 @@
 #include <stan/math/error_handling/matrix/check_symmetric.hpp>
 #include <stan/math/error_handling/matrix/check_square.hpp>
 
-
 namespace stan {
   namespace math {
 
@@ -30,25 +29,13 @@ namespace stan {
                  const Eigen::Matrix<T_y,Eigen::Dynamic,Eigen::Dynamic>& y,
                  const char* name,
                  T_result* result) {
-      if (!check_square(function, y, name, result))
-        return false;
-      if (!check_positive(function, y.rows(), "rows", result))
-        return false;
-      if (!check_symmetric(function, y, name, result))
-        return false;
-      if (!check_pos_semidefinite(function, y, name, result))
-        return false;
+      check_square(function, y, name, result);
+      check_positive(function, y.rows(), "rows", result);
+      check_symmetric(function, y, name, result);
+      check_pos_semidefinite(function, y, name, result);
       return true;
     }
 
-    template <typename T>
-    inline bool check_spsd_matrix(const char* function,
-                                  const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& y,
-                                  const char* name,
-                                  T* result = 0) {
-      return check_spsd_matrix<T,T>(function,y,name,result);
-    }
-
   }
 }
 #endif
