@@ -3,7 +3,7 @@
 
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_matching_sizes.hpp>
+#include <stan/math/error_handling/matrix/check_matching_sizes.hpp>
 
 namespace stan {
   namespace math {
@@ -21,7 +21,8 @@ namespace stan {
     inline Eigen::Matrix<double, 1, C1>
     columns_dot_product(const Eigen::Matrix<double, R1, C1>& v1, 
                         const Eigen::Matrix<double, R2, C2>& v2) {
-      validate_matching_sizes(v1,v2,"columns_dot_product");
+      stan::math::check_matching_sizes("columns_dot_product(%1%)",v1,"v1",
+                                       v2,"v2",(double*)0);
       Eigen::Matrix<double, 1, C1> ret(1,v1.cols());
       for (size_type j = 0; j < v1.cols(); ++j) {
         ret(j) = v1.col(j).dot(v2.col(j));
