@@ -1,9 +1,9 @@
 #ifndef __STAN__MATH__MATRIX__EIGENVALUES_SYM_HPP__
 #define __STAN__MATH__MATRIX__EIGENVALUES_SYM_HPP__
 
+#include <stan/math/error_handling/matrix/check_nonzero_size.hpp>
+#include <stan/math/error_handling/matrix/check_symmetric.hpp>
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_nonzero_size.hpp>
-#include <stan/math/matrix/validate_symmetric.hpp>
 
 namespace stan {
   namespace math {
@@ -20,8 +20,10 @@ namespace stan {
     template <typename T>
     Eigen::Matrix<T,Eigen::Dynamic,1>
     eigenvalues_sym(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& m) {
-      validate_nonzero_size(m,"eigenvalues_sym");
-      validate_symmetric(m,"eigenvalues_sym");
+      stan::math::check_nonzero_size("eigenvalues_sym(%1%)",m,
+                                     "m",(double*)0);
+      stan::math::check_symmetric("eigenvalues_sym(%1%)",m,"m",(double*)0);
+
       Eigen::SelfAdjointEigenSolver<Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> >
         solver(m,Eigen::EigenvaluesOnly);
       return solver.eigenvalues();
