@@ -1,21 +1,30 @@
 #ifndef __STAN__MATH__MATRIX_ERROR_HANDLING_HPP__
 #define __STAN__MATH__MATRIX_ERROR_HANDLING_HPP__
 
-#include <stan/math/error_handling/matrix/constraint_tolerance.hpp>
-#include <stan/math/error_handling/matrix/check_size_match.hpp>
+#include <stan/math/error_handling/matrix/check_cholesky_factor.hpp>
+#include <stan/math/error_handling/matrix/check_column_index.hpp>
+#include <stan/math/error_handling/matrix/check_corr_matrix.hpp>
+#include <stan/math/error_handling/matrix/check_cov_matrix.hpp>
+#include <stan/math/error_handling/matrix/check_ldlt_factor.hpp>
 #include <stan/math/error_handling/matrix/check_lower_triangular.hpp>
-#include <stan/math/error_handling/matrix/check_symmetric.hpp>
+#include <stan/math/error_handling/matrix/check_matching_dims.hpp>
+#include <stan/math/error_handling/matrix/check_matching_sizes.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_nonzero_size.hpp>
+#include <stan/math/error_handling/matrix/check_ordered.hpp>
 #include <stan/math/error_handling/matrix/check_pos_definite.hpp>
 #include <stan/math/error_handling/matrix/check_pos_semidefinite.hpp>
-#include <stan/math/error_handling/matrix/check_cholesky_factor.hpp>
-#include <stan/math/error_handling/matrix/check_cov_matrix.hpp>
-#include <stan/math/error_handling/matrix/check_corr_matrix.hpp>
-#include <stan/math/error_handling/matrix/check_unit_vector.hpp>
-#include <stan/math/error_handling/matrix/check_simplex.hpp>
-#include <stan/math/error_handling/matrix/check_ordered.hpp>
 #include <stan/math/error_handling/matrix/check_positive_ordered.hpp>
+#include <stan/math/error_handling/matrix/check_row_index.hpp>
+#include <stan/math/error_handling/matrix/check_simplex.hpp>
+#include <stan/math/error_handling/matrix/check_size_match.hpp>
 #include <stan/math/error_handling/matrix/check_spsd_matrix.hpp>
 #include <stan/math/error_handling/matrix/check_square.hpp>
+#include <stan/math/error_handling/matrix/check_std_vector_index.hpp>
+#include <stan/math/error_handling/matrix/check_symmetric.hpp>
+#include <stan/math/error_handling/matrix/check_unit_vector.hpp>
+#include <stan/math/error_handling/matrix/check_vector.hpp>
+#include <stan/math/error_handling/matrix/constraint_tolerance.hpp>
 #include <stan/math/error_handling/matrix/validate_non_negative_index.hpp>
 
 #endif
