@@ -58,8 +58,7 @@ namespace stan {
       using stan::math::check_positive;
       
       typename promote_args<T_covar,T_shape>::type lp(0.0);
-      if (!check_positive(function, eta, "Shape parameter", &lp))
-        return lp;      
+      check_positive(function, eta, "Shape parameter", &lp);
 
       const unsigned int K = L.rows();
       if (K == 0)
@@ -102,18 +101,13 @@ namespace stan {
       using boost::math::tools::promote_args;
       
       typename promote_args<T_y,T_shape>::type lp;
-      if (!check_positive(function, eta, "Shape parameter", &lp))
-        return lp;      
-      if (!check_size_match(function, 
-          y.rows(), "Rows of correlation matrix",
-          y.cols(), "columns of correlation matrix",
-          &lp))
-        return lp;
-      if (!check_not_nan(function, y, "Correlation matrix", &lp)) 
-        return lp;
-      if (!check_corr_matrix(function, y, "Correlation matrix", &lp)) {
-        return lp;
-      }
+      check_positive(function, eta, "Shape parameter", &lp);
+      check_size_match(function, 
+                       y.rows(), "Rows of correlation matrix",
+                       y.cols(), "columns of correlation matrix",
+                       &lp);
+      check_not_nan(function, y, "Correlation matrix", &lp);
+      check_corr_matrix(function, y, "Correlation matrix", &lp);
       
       const unsigned int K = y.rows();
       if (K == 0)
@@ -146,7 +140,7 @@ namespace stan {
 
       using stan::math::check_positive;
       
-      check_positive(function, eta, "Shape parameter");
+      check_positive(function, eta, "Shape parameter", (double*)0);
 
       Eigen::ArrayXd CPCs( (K * (K - 1)) / 2 );
       double alpha = eta + 0.5 * (K - 1);
@@ -172,7 +166,7 @@ namespace stan {
 
       using stan::math::check_positive;
       
-      check_positive(function, eta, "Shape parameter");
+      check_positive(function, eta, "Shape parameter", (double*)0);
 
       using stan::math::multiply_lower_tri_self_transpose;
       return multiply_lower_tri_self_transpose(
