@@ -10,14 +10,11 @@
 #include <stan/meta/traits.hpp>
 #include <stan/prob/constants.hpp>
 #include <stan/prob/traits.hpp>
+#include <stan/math/functions/sign.hpp>
 
 namespace stan {
 
   namespace prob {
-    template<typename T>
-    inline int sign(const T& z) {
-      return (z == 0) ? 0 : z < 0 ? -1 : 1;
-    }
 
     // DoubleExponential(y|mu,sigma)  [sigma > 0]
     // FIXME: add documentation
@@ -37,6 +34,7 @@ namespace stan {
       using stan::prob::include_summand;
       using std::log;
       using std::fabs;
+      using stan::math::sign;
 
       // check if any vectors are zero length
       if (!(stan::length(y) 
@@ -46,22 +44,13 @@ namespace stan {
 
       // set up return value accumulator
       double logp(0.0);
-      if(!check_finite(function, y, "Random variable", &logp))
-        return logp;
-      if(!check_finite(function, mu, "Location parameter", 
-                       &logp))
-        return logp;
-      if(!check_finite(function, sigma, "Scale parameter", 
-                       &logp))
-        return logp;
-      if(!check_positive(function, sigma, "Scale parameter", 
-                         &logp))
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   y,mu,sigma,
-                                   "Random variable","Location parameter","Shape parameter",
-                                   &logp)))
-        return logp;
+      check_finite(function, y, "Random variable", &logp);
+      check_finite(function, mu, "Location parameter", &logp);
+      check_finite(function, sigma, "Scale parameter", &logp);
+      check_positive(function, sigma, "Scale parameter", &logp);
+      check_consistent_sizes(function,y,mu,sigma,
+                             "Random variable","Location parameter",
+                             "Shape parameter",&logp);
       
       // check if no variables are involved and prop-to
       if (!include_summand<propto,T_y,T_loc,T_scale>::value)
@@ -164,14 +153,10 @@ namespace stan {
       using boost::math::tools::promote_args;
 
       double cdf(1.0);
-      if(!check_not_nan(function, y, "Random variable", &cdf))
-        return cdf;
-      if(!check_finite(function, mu, "Location parameter", &cdf))
-        return cdf;
-      if(!check_finite(function, sigma, "Scale parameter", &cdf))
-        return cdf;
-      if(!check_positive(function, sigma, "Scale parameter", &cdf))
-        return cdf;
+      check_not_nan(function, y, "Random variable", &cdf);
+      check_finite(function, mu, "Location parameter", &cdf);
+      check_finite(function, sigma, "Scale parameter", &cdf);
+      check_positive(function, sigma, "Scale parameter", &cdf);
 
       agrad::OperandsAndPartials<T_y, T_loc, T_scale> 
         operands_and_partials(y, mu, sigma);
@@ -248,18 +233,13 @@ namespace stan {
             && stan::length(sigma)))
         return cdf_log;
 
-      if(!check_not_nan(function, y, "Random variable", &cdf_log))
-        return cdf_log;
-      if(!check_finite(function, mu, "Location parameter", &cdf_log))
-        return cdf_log;
-      if(!check_finite(function, sigma, "Scale parameter", &cdf_log))
-        return cdf_log;
-      if(!check_positive(function, sigma, "Scale parameter", &cdf_log))
-        return cdf_log;
-      if (!(check_consistent_sizes(function, y, mu, sigma,
-                                   "Random variable", "Location parameter", 
-                                   "Scale Parameter", &cdf_log)))
-        return cdf_log;
+      check_not_nan(function, y, "Random variable", &cdf_log);
+      check_finite(function, mu, "Location parameter", &cdf_log);
+      check_finite(function, sigma, "Scale parameter", &cdf_log);
+      check_positive(function, sigma, "Scale parameter", &cdf_log);
+      check_consistent_sizes(function, y, mu, sigma,
+                             "Random variable", "Location parameter", 
+                             "Scale Parameter", &cdf_log);
       
       using std::log;
       using std::exp;
@@ -330,18 +310,13 @@ namespace stan {
             && stan::length(sigma)))
         return ccdf_log;
 
-      if(!check_not_nan(function, y, "Random variable", &ccdf_log))
-        return ccdf_log;
-      if(!check_finite(function, mu, "Location parameter", &ccdf_log))
-        return ccdf_log;
-      if(!check_finite(function, sigma, "Scale parameter", &ccdf_log))
-        return ccdf_log;
-      if(!check_positive(function, sigma, "Scale parameter", &ccdf_log))
-        return ccdf_log;
-      if (!(check_consistent_sizes(function, y, mu, sigma,
-                                   "Random variable", "Location parameter", 
-                                   "Scale Parameter", &ccdf_log)))
-        return ccdf_log;
+      check_not_nan(function, y, "Random variable", &ccdf_log);
+      check_finite(function, mu, "Location parameter", &ccdf_log);
+      check_finite(function, sigma, "Scale parameter", &ccdf_log);
+      check_positive(function, sigma, "Scale parameter", &ccdf_log);
+      check_consistent_sizes(function, y, mu, sigma,
+                             "Random variable", "Location parameter", 
+                             "Scale Parameter", &ccdf_log);
       
       using std::log;
       using std::exp;
@@ -407,12 +382,9 @@ namespace stan {
       using stan::math::check_finite;
       using stan::math::check_positive;
 
-      if(!check_finite(function, mu, "Location parameter"))
-        return 0;
-      if(!check_finite(function, sigma, "Scale parameter"))
-        return 0;
-      if(!check_positive(function, sigma, "Scale parameter"))
-        return 0;
+      check_finite(function, mu, "Location parameter", (double*)0);
+      check_finite(function, sigma, "Scale parameter", (double*)0);
+      check_positive(function, sigma, "Scale parameter", (double*)0);
 
       variate_generator<RNG&, uniform_01<> >
         rng_unit_01(rng, uniform_01<>());
