@@ -64,25 +64,16 @@ namespace stan {
       double logp(0.0);
 
       // validate args (here done over var, which should be OK)
-      if (!check_not_nan(function, y, "Random variable", &logp))
-        return logp;
-      if (!check_finite(function, alpha, "Shape parameter", 
-                        &logp)) 
-        return logp;
-      if (!check_positive(function, alpha, "Shape parameter", 
-                          &logp)) 
-        return logp;
-      if (!check_finite(function, beta, "Inverse scale parameter", 
-                        &logp)) 
-        return logp;
-      if (!check_positive(function, beta, "Inverse scale parameter", 
-                          &logp)) 
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   y,alpha,beta,
-                                   "Random variable","Shape parameter","Inverse scale parameter",
-                                   &logp)))
-        return logp;
+      check_not_nan(function, y, "Random variable", &logp);
+      check_finite(function, alpha, "Shape parameter", &logp);
+      check_positive(function, alpha, "Shape parameter", &logp); 
+      check_finite(function, beta, "Inverse scale parameter", &logp); 
+      check_positive(function, beta, "Inverse scale parameter", &logp);
+      check_consistent_sizes(function,
+                             y,alpha,beta,
+                             "Random variable","Shape parameter",
+                             "Inverse scale parameter",
+                             &logp);
 
       // check if no variables are involved and prop-to
       if (!include_summand<propto,T_y,T_shape,T_inv_scale>::value)
@@ -201,23 +192,16 @@ namespace stan {
           
       double P(1.0);
           
-      if (!check_finite(function, alpha, "Shape parameter", &P)) 
-        return P;
-      if (!check_positive(function, alpha, "Shape parameter", &P)) 
-        return P;
-      if (!check_finite(function, beta, "Scale parameter", &P)) 
-        return P;
-      if (!check_positive(function, beta, "Scale parameter", &P)) 
-        return P;
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P)) 
-        return P;
-      if (!(check_consistent_sizes(function, y, alpha, beta,
-                                   "Random variable", "Shape parameter", 
-                                   "Scale Parameter",
-                                   &P)))
-        return P;
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P); 
+      check_finite(function, beta, "Scale parameter", &P);
+      check_positive(function, beta, "Scale parameter", &P); 
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P); 
+      check_consistent_sizes(function, y, alpha, beta,
+                             "Random variable", "Shape parameter", 
+                             "Scale Parameter",
+                             &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -324,23 +308,16 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_finite(function, alpha, "Shape parameter", &P)) 
-        return P;
-      if (!check_positive(function, alpha, "Shape parameter", &P)) 
-        return P;
-      if (!check_finite(function, beta, "Scale parameter", &P)) 
-        return P;
-      if (!check_positive(function, beta, "Scale parameter", &P)) 
-        return P;
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P)) 
-        return P;
-      if (!(check_consistent_sizes(function, y, alpha, beta,
-                                   "Random variable", "Shape parameter", 
-                                   "Scale Parameter",
-                                   &P)))
-        return P;
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P); 
+      check_finite(function, beta, "Scale parameter", &P);
+      check_positive(function, beta, "Scale parameter", &P); 
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P); 
+      check_consistent_sizes(function, y, alpha, beta,
+                             "Random variable", "Shape parameter", 
+                             "Scale Parameter",
+                             &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -437,23 +414,16 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_finite(function, alpha, "Shape parameter", &P)) 
-        return P;
-      if (!check_positive(function, alpha, "Shape parameter", &P)) 
-        return P;
-      if (!check_finite(function, beta, "Scale parameter", &P)) 
-        return P;
-      if (!check_positive(function, beta, "Scale parameter", &P)) 
-        return P;
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P)) 
-        return P;
-      if (!(check_consistent_sizes(function, y, alpha, beta,
-                                   "Random variable", "Shape parameter", 
-                                   "Scale Parameter",
-                                   &P)))
-        return P;
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P); 
+      check_finite(function, beta, "Scale parameter", &P);
+      check_positive(function, beta, "Scale parameter", &P); 
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P); 
+      check_consistent_sizes(function, y, alpha, beta,
+                             "Random variable", "Shape parameter", 
+                             "Scale Parameter",
+                             &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -541,14 +511,10 @@ namespace stan {
       using stan::math::check_finite;
       using stan::math::check_positive;
       
-      if (!check_finite(function, alpha, "Shape parameter")) 
-        return 0;
-      if (!check_positive(function, alpha, "Shape parameter")) 
-        return 0;
-      if (!check_finite(function, beta, "Inverse scale parameter"))
-        return 0;
-      if (!check_positive(function, beta, "Inverse scale parameter"))
-        return 0;
+      check_finite(function, alpha, "Shape parameter", (double*)0);
+      check_positive(function, alpha, "Shape parameter", (double*)0);
+      check_finite(function, beta, "Inverse scale parameter", (double*)0);
+      check_positive(function, beta, "Inverse scale parameter", (double*)0);
 
       /*
         the boost gamma distribution is defined by
