@@ -60,20 +60,14 @@ namespace stan {
       double logp(0.0);
 
       // validate args (here done over var, which should be OK)
-      if (!check_not_nan(function, y, "Random variable", &logp))
-        return logp;
-      if (!check_finite(function, mu, "Location parameter", 
-                        &logp))
-        return logp;
-      if (!check_positive(function, sigma, "Scale parameter", 
-                          &logp))
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   y,mu,sigma,
-                                   "Random variable","Location parameter","Scale parameter",
-                                   &logp)))
-        return logp;
-
+      check_not_nan(function, y, "Random variable", &logp);
+      check_finite(function, mu, "Location parameter", &logp);
+      check_positive(function, sigma, "Scale parameter", &logp);
+      check_consistent_sizes(function,
+                             y,mu,sigma,
+                             "Random variable","Location parameter",
+                             "Scale parameter",
+                             &logp);
       // check if no variables are involved and prop-to
       if (!include_summand<propto,T_y,T_loc,T_scale>::value)
         return 0.0;
@@ -172,22 +166,15 @@ namespace stan {
             && stan::length(sigma)))
         return cdf;
 
-      if (!check_not_nan(function, y, "Random variable", &cdf))
-        return cdf;
-      if (!check_finite(function, mu, "Location parameter", &cdf))
-        return cdf;
-      if (!check_not_nan(function, sigma, "Scale parameter", 
-                         &cdf))
-        return cdf;
-      if (!check_positive(function, sigma, "Scale parameter", 
-                          &cdf))
-        return cdf;
-      if (!(check_consistent_sizes(function,
-                                   y,mu,sigma,
-                                   "Random variable","Location parameter",
-                                   "Scale parameter",
-                                   &cdf)))
-        return cdf;
+      check_not_nan(function, y, "Random variable", &cdf);
+      check_finite(function, mu, "Location parameter", &cdf);
+      check_not_nan(function, sigma, "Scale parameter", &cdf);
+      check_positive(function, sigma, "Scale parameter", &cdf);
+      check_consistent_sizes(function,
+                             y,mu,sigma,
+                             "Random variable","Location parameter",
+                             "Scale parameter",
+                             &cdf);
 
      agrad::OperandsAndPartials<T_y, T_loc, T_scale> 
        operands_and_partials(y, mu, sigma);
@@ -250,21 +237,14 @@ namespace stan {
             && stan::length(sigma)))
         return cdf_log;
 
-      if (!check_not_nan(function, y, "Random variable", &cdf_log))
-        return cdf_log;
-      if (!check_finite(function, mu, "Location parameter", &cdf_log))
-        return cdf_log;
-      if (!check_not_nan(function, sigma, "Scale parameter", 
-                         &cdf_log))
-        return cdf_log;
-      if (!check_positive(function, sigma, "Scale parameter", 
-                          &cdf_log))
-        return cdf_log;
-      if (!(check_consistent_sizes(function,
-                                   y,mu,sigma,
-                                   "Random variable","Location parameter",
-                                   "Scale parameter", &cdf_log)))
-        return cdf_log;
+      check_not_nan(function, y, "Random variable", &cdf_log);
+      check_finite(function, mu, "Location parameter", &cdf_log);
+      check_not_nan(function, sigma, "Scale parameter", &cdf_log);
+      check_positive(function, sigma, "Scale parameter", &cdf_log);
+      check_consistent_sizes(function,
+                             y,mu,sigma,
+                             "Random variable","Location parameter",
+                             "Scale parameter", &cdf_log);
 
       agrad::OperandsAndPartials<T_y, T_loc, T_scale> 
         operands_and_partials(y, mu, sigma);
@@ -319,21 +299,14 @@ namespace stan {
             && stan::length(sigma)))
         return ccdf_log;
 
-      if (!check_not_nan(function, y, "Random variable", &ccdf_log))
-        return ccdf_log;
-      if (!check_finite(function, mu, "Location parameter", &ccdf_log))
-        return ccdf_log;
-      if (!check_not_nan(function, sigma, "Scale parameter", 
-                         &ccdf_log))
-        return ccdf_log;
-      if (!check_positive(function, sigma, "Scale parameter", 
-                          &ccdf_log))
-        return ccdf_log;
-      if (!(check_consistent_sizes(function,
-                                   y,mu,sigma,
-                                   "Random variable","Location parameter",
-                                   "Scale parameter", &ccdf_log)))
-        return ccdf_log;
+      check_not_nan(function, y, "Random variable", &ccdf_log);
+      check_finite(function, mu, "Location parameter", &ccdf_log);
+      check_not_nan(function, sigma, "Scale parameter", &ccdf_log);
+      check_positive(function, sigma, "Scale parameter", &ccdf_log);
+      check_consistent_sizes(function,
+                             y,mu,sigma,
+                             "Random variable","Location parameter",
+                             "Scale parameter", &ccdf_log);
 
       agrad::OperandsAndPartials<T_y, T_loc, T_scale>
         operands_and_partials(y, mu, sigma);
@@ -383,14 +356,10 @@ namespace stan {
 
       static const char* function = "stan::prob::normal_rng(%1%)";
 
-      if (!check_finite(function, mu, "Location parameter"))
-        return 0;
-      if (!check_not_nan(function, mu, "Location parameter"))
-        return 0;
-      if (!check_positive(function, sigma, "Scale parameter"))
-        return 0;
-       if (!check_not_nan(function, sigma, "Scale parameter"))
-        return 0;
+      check_finite(function, mu, "Location parameter", (double*)0);
+      check_not_nan(function, mu, "Location parameter", (double*)0);
+      check_positive(function, sigma, "Scale parameter", (double*)0);
+      check_not_nan(function, sigma, "Scale parameter", (double*)0);
 
       variate_generator<RNG&, normal_distribution<> >
         norm_rng(rng, normal_distribution<>(mu, sigma));
